## 1.1.2 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 1.1.1 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 1.1.0 (2022-02-23)

Update dateparser stubs for 1.1 (#7368)

## 1.0.14 (2022-02-03)

Improve `__enter__` & constructor methods (#7114)

## 1.0.13 (2022-01-22)

fix incorrect tuple[T] (#6996)

Found from PyCQA/flake8-pyi#135.

## 1.0.12 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 1.0.10 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 1.0.9 (2021-12-27)

Always alias `collections.abc.Set` (#6712)

## 1.0.8 (2021-11-23)

Reduce use of deprecated `typing` aliases (#6358)

## 1.0.7 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 1.0.6 (2021-10-14)

check_new_syntax.py: check nested annotations (#6167)

## 1.0.5 (2021-10-13)

dateparser.search.search_dates: allow arbitrary-length tuples for languages argument (#6166)

Cleanup: use lower-case list and dict, add a test (#6161)

## 1.0.4 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 1.0.3 (2021-09-27)

Specify concrete types for DateDataParser attributes (#6075)

